import { EVENT_MANAGER_PLUGINS } from '@angular/platform-browser';
import { EMPTY } from 'rxjs';
import { take, switchMap } from 'rxjs/operators';

class BsBindEventPlugin {
    supports(event) {
        return event.startsWith('$.');
    }
    addEventListener(element, event) {
        const el = element;
        el[event] = EMPTY;
        const method = this.getMethod(element, event);
        const sub = this.manager.getZone()
            .onStable.pipe(take(1), switchMap(() => el[event]))
            .subscribe((value) => method(value));
        return () => sub.unsubscribe();
    }
    getMethod(element, event) {
        const el = element;
        const [, key, value, unit = ''] = event.split('.');
        if (event.endsWith('.attr')) {
            return (v) => element.setAttribute(key, String(v));
        }
        if (key === 'class') {
            return (v) => element.classList.toggle(value, !!v);
        }
        if (key === 'style') {
            return (v) => element.style.setProperty(value, `${v}${unit}`);
        }
        return (v) => (el[key] = v);
    }
}

function provideAsyncHostBindings() {
    return [{
            provide: EVENT_MANAGER_PLUGINS,
            useClass: BsBindEventPlugin,
            multi: true,
        }];
}

/**
 * Generated bundle index. Do not edit.
 */

export { BsBindEventPlugin, provideAsyncHostBindings };
//# sourceMappingURL=mintplayer-ng-bootstrap-async-host-binding.mjs.map
