import { AsyncPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { EventEmitter, Component, Output, Input } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { BehaviorSubject, map, filter, take } from 'rxjs';
import * as i2 from '@mintplayer/ng-bootstrap/calendar-month';
import { BsMonthNamePipe, BsWeekdayNamePipe } from '@mintplayer/ng-bootstrap/calendar-month';
import * as i1 from '@angular/platform-browser';
import { BsLetDirective } from '@mintplayer/ng-bootstrap/let';
import { BsUcFirstPipe } from '@mintplayer/ng-bootstrap/uc-first';

/// <reference types="./types" />
/// <reference types="./types" />
class BsCalendarComponent {
    constructor(sanitizer, calendarMonthService) {
        this.sanitizer = sanitizer;
        this.calendarMonthService = calendarMonthService;
        //#region CurrentMonth
        this.currentMonth$ = new BehaviorSubject(new Date());
        this.currentMonthChange = new EventEmitter();
        //#endregion
        //#region SelectedDate
        this.selectedDate$ = new BehaviorSubject(new Date());
        this.selectedDateChange = new EventEmitter();
        this.weeks$ = this.currentMonth$
            .pipe(map((month) => this.calendarMonthService.getWeeks(month)));
        this.shownDays$ = this.weeks$
            .pipe(filter((weeks) => weeks.length > 1))
            .pipe(map((weeks) => weeks[1].days))
            .pipe(map((days) => {
            const firstDay = days[0];
            if (firstDay) {
                return days.map((d) => {
                    const date = new Date(firstDay.date.getFullYear(), firstDay.date.getMonth(), d?.dayOfMonth);
                    return {
                        short: date.toLocaleString('default', { weekday: 'short' }),
                        long: date.toLocaleString('default', { weekday: 'long' })
                    };
                });
            }
            else {
                return [];
            }
        }));
        this.selectedDate$.pipe(takeUntilDestroyed())
            .subscribe(date => this.selectedDateChange.emit(date));
        this.currentMonth$.pipe(takeUntilDestroyed())
            .subscribe(month => this.currentMonthChange.emit(month));
        import('bootstrap-icons/icons/chevron-left.svg').then((icon) => {
            this.chevronLeft = sanitizer.bypassSecurityTrustHtml(icon.default);
        });
        import('bootstrap-icons/icons/chevron-right.svg').then((icon) => {
            this.chevronRight = sanitizer.bypassSecurityTrustHtml(icon.default);
        });
    }
    get currentMonth() {
        return this.currentMonth$.value;
    }
    set currentMonth(value) {
        this.currentMonth$.next(value);
    }
    get selectedDate() {
        return this.selectedDate$.value;
    }
    set selectedDate(value) {
        this.selectedDate$.next(value);
    }
    previousMonth() {
        this.currentMonth$.pipe(take(1)).subscribe((month) => {
            this.currentMonth$.next(new Date(month.getFullYear(), month.getMonth() - 1, 1));
        });
        return false;
    }
    nextMonth() {
        this.currentMonth$.pipe(take(1)).subscribe((month) => {
            this.currentMonth$.next(new Date(month.getFullYear(), month.getMonth() + 1, 1));
        });
        return false;
    }
    isSameDate(date1, date2) {
        if (date1 === null && date2 === null)
            return true;
        if (date1 === null || date2 === null)
            return false;
        return (date1.getFullYear() === date2.getFullYear() &&
            date1.getMonth() === date2.getMonth() &&
            date1.getDate() === date2.getDate());
    }
    goto(day) {
        if (day && day.isInMonth && (!this.disableDateFn || !this.disableDateFn(day.date))) {
            this.selectedDate$.next(day.date);
        }
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsCalendarComponent, deps: [{ token: i1.DomSanitizer }, { token: i2.BsCalendarMonthService }], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.1", type: BsCalendarComponent, isStandalone: true, selector: "bs-calendar", inputs: { currentMonth: "currentMonth", selectedDate: "selectedDate", disableDateFn: "disableDateFn" }, outputs: { currentMonthChange: "currentMonthChange", selectedDateChange: "selectedDateChange" }, ngImport: i0, template: "<table class=\"table w-auto mb-0\">\n    <tr>\n        <td>\n            <button class=\"btn btn-default\" (click)=\"previousMonth()\">\n                <span [innerHTML]=\"chevronLeft\" class=\"fw-bolder\"></span>\n            </button>\n        </td>\n        <td colspan=\"6\" class=\"fw-bolder\">\n            {{ currentMonth$ | async | monthName | bsUcFirst }}\n            {{ (currentMonth$ | async)?.getFullYear() }}\n        </td>\n        <td>\n            <button class=\"btn btn-default border-bottom-0\" (click)=\"nextMonth()\">\n                <span [innerHTML]=\"chevronRight\" class=\"fw-bolder\"></span>\n            </button>\n        </td>\n    </tr>\n    <tr>\n        <th></th>\n        @for (dayOfWeek of shownDays$ | async; track dayOfWeek.long) {\n            <th [title]=\"dayOfWeek.long\">\n                {{ dayOfWeek.short }}\n            </th>\n        }\n    </tr>\n    @for (week of (weeks$ | async); track week.number) {\n        <tr>\n            <th>\n                {{ week.number }}\n            </th>\n            @for (day of week.days; track day?.date) {\n                <ng-container *bsLet=\"((day !== null) && day.isInMonth) as showSpan\">\n                    <ng-container *bsLet=\"(disableDateFn && disableDateFn(day.date)) as disabled\">\n                        <td [class.selected]=\"day === null ? false : !day.isInMonth ? false : isSameDate(selectedDate$ | async, day.date)\" [class.cursor-pointer]=\"showSpan && !disabled\" (click)=\"goto(day)\">\n                            @if (showSpan) {\n                                <span [class.text-muted]=\"disabled\">{{ day.dayOfMonth }}</span>\n                            }\n                        </td>\n                    </ng-container>\n                </ng-container>\n            }\n        </tr>\n    }\n</table>", styles: [".text-muted{color:#9ea7af!important}table{border-collapse:collapse;border:1px solid var(--bs-border-color);background:#fff}table td,table th{width:40px;height:40px;text-align:center;cursor:default}table td span,table th span{white-space:nowrap}table td.selected{background-color:#0d6efd;color:#fff}table th{background-color:#f8f9fa}table tr{border-top:none}table tr:first-child>td{border-bottom:1px solid var(--bs-border-color)}table tr:nth-of-type(2)>th:not(:nth-of-type(1)){border-bottom:1px solid var(--bs-border-color)}table tr:not(:nth-of-type(2))>th:nth-of-type(1){border-right:1px solid var(--bs-border-color)}\n"], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }, { kind: "directive", type: BsLetDirective, selector: "[bsLet]", inputs: ["bsLet"] }, { kind: "pipe", type: BsUcFirstPipe, name: "bsUcFirst" }, { kind: "pipe", type: BsMonthNamePipe, name: "monthName" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsCalendarComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-calendar', standalone: true, imports: [AsyncPipe, BsLetDirective, BsUcFirstPipe, BsMonthNamePipe, BsWeekdayNamePipe], template: "<table class=\"table w-auto mb-0\">\n    <tr>\n        <td>\n            <button class=\"btn btn-default\" (click)=\"previousMonth()\">\n                <span [innerHTML]=\"chevronLeft\" class=\"fw-bolder\"></span>\n            </button>\n        </td>\n        <td colspan=\"6\" class=\"fw-bolder\">\n            {{ currentMonth$ | async | monthName | bsUcFirst }}\n            {{ (currentMonth$ | async)?.getFullYear() }}\n        </td>\n        <td>\n            <button class=\"btn btn-default border-bottom-0\" (click)=\"nextMonth()\">\n                <span [innerHTML]=\"chevronRight\" class=\"fw-bolder\"></span>\n            </button>\n        </td>\n    </tr>\n    <tr>\n        <th></th>\n        @for (dayOfWeek of shownDays$ | async; track dayOfWeek.long) {\n            <th [title]=\"dayOfWeek.long\">\n                {{ dayOfWeek.short }}\n            </th>\n        }\n    </tr>\n    @for (week of (weeks$ | async); track week.number) {\n        <tr>\n            <th>\n                {{ week.number }}\n            </th>\n            @for (day of week.days; track day?.date) {\n                <ng-container *bsLet=\"((day !== null) && day.isInMonth) as showSpan\">\n                    <ng-container *bsLet=\"(disableDateFn && disableDateFn(day.date)) as disabled\">\n                        <td [class.selected]=\"day === null ? false : !day.isInMonth ? false : isSameDate(selectedDate$ | async, day.date)\" [class.cursor-pointer]=\"showSpan && !disabled\" (click)=\"goto(day)\">\n                            @if (showSpan) {\n                                <span [class.text-muted]=\"disabled\">{{ day.dayOfMonth }}</span>\n                            }\n                        </td>\n                    </ng-container>\n                </ng-container>\n            }\n        </tr>\n    }\n</table>", styles: [".text-muted{color:#9ea7af!important}table{border-collapse:collapse;border:1px solid var(--bs-border-color);background:#fff}table td,table th{width:40px;height:40px;text-align:center;cursor:default}table td span,table th span{white-space:nowrap}table td.selected{background-color:#0d6efd;color:#fff}table th{background-color:#f8f9fa}table tr{border-top:none}table tr:first-child>td{border-bottom:1px solid var(--bs-border-color)}table tr:nth-of-type(2)>th:not(:nth-of-type(1)){border-bottom:1px solid var(--bs-border-color)}table tr:not(:nth-of-type(2))>th:nth-of-type(1){border-right:1px solid var(--bs-border-color)}\n"] }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }, { type: i2.BsCalendarMonthService }], propDecorators: { currentMonthChange: [{
                type: Output
            }], currentMonth: [{
                type: Input
            }], selectedDateChange: [{
                type: Output
            }], selectedDate: [{
                type: Input
            }], disableDateFn: [{
                type: Input
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { BsCalendarComponent };
//# sourceMappingURL=mintplayer-ng-bootstrap-calendar.mjs.map
