import * as i0 from '@angular/core';
import { SecurityContext, Pipe } from '@angular/core';
import * as i1 from '@angular/platform-browser';

class BsBoldPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(value, numberOfStars = 2, classList = []) {
        const txt = `\\*{${numberOfStars}}\\b(?<boldtext>[^\\*]+)\\b\\*{${numberOfStars}}`;
        const rgx = new RegExp(txt, "gm");
        const safeValue = this.domSanitizer.sanitize(SecurityContext.HTML, value);
        if (!safeValue) {
            return null;
        }
        const classString = classList.length === 0 ? '' : ` class="${classList.join(' ')}"`;
        const result = safeValue.replace(rgx, `<b${classString}>$<boldtext></b>`);
        const safeResult = this.domSanitizer.bypassSecurityTrustHtml(result);
        return safeResult;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsBoldPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.1", ngImport: i0, type: BsBoldPipe, isStandalone: true, name: "bsBold" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsBoldPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'bsBold',
                    pure: true,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class BsItalicPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(value, numberOfStars = 1, classList = []) {
        const txt = `\\*{${numberOfStars}}\\b(?<italictext>[^\\*]+)\\b\\*{${numberOfStars}}`;
        const rgx = new RegExp(txt, "gm");
        const safeValue = this.domSanitizer.sanitize(SecurityContext.HTML, value);
        if (!safeValue) {
            return null;
        }
        const classString = classList.length === 0 ? '' : ` class="${classList.join(' ')}"`;
        const result = safeValue.replace(rgx, `<i${classString}>$<italictext></i>`);
        const safeResult = this.domSanitizer.bypassSecurityTrustHtml(result);
        return safeResult;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsItalicPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.1", ngImport: i0, type: BsItalicPipe, isStandalone: true, name: "bsItalic" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsItalicPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'bsItalic',
                    pure: true,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class BsStrikethroughPipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(value, numberOfTildes = 2, classList = []) {
        const txt = `\\~{${numberOfTildes}}\\b(?<strikethroughtext>[^\\~]+)\\b\\~{${numberOfTildes}}`;
        const rgx = new RegExp(txt, "gm");
        const safeValue = this.domSanitizer.sanitize(SecurityContext.HTML, value);
        if (!safeValue) {
            return null;
        }
        const classString = classList.length === 0 ? '' : ` class="${classList.join(' ')}"`;
        const result = safeValue.replace(rgx, `<strike${classString}>$<strikethroughtext></strike>`);
        const safeResult = this.domSanitizer.bypassSecurityTrustHtml(result);
        return safeResult;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsStrikethroughPipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.1", ngImport: i0, type: BsStrikethroughPipe, isStandalone: true, name: "bsStrikethrough" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsStrikethroughPipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'bsStrikethrough',
                    pure: true,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

class BsUnderlinePipe {
    constructor(domSanitizer) {
        this.domSanitizer = domSanitizer;
    }
    transform(value, classList = []) {
        const txt = `\\<ins\\>\\b(?<underlinedtext>.+?)\\b\\<\\/ins\\>`;
        const rgx = new RegExp(txt, "gm");
        const safeValue = this.domSanitizer.sanitize(SecurityContext.HTML, value);
        if (!safeValue) {
            return null;
        }
        const classString = classList.length === 0 ? '' : ` class="${classList.join(' ')}"`;
        const result = safeValue.replace(rgx, `<u${classString}>$<underlinedtext></u>`);
        const safeResult = this.domSanitizer.bypassSecurityTrustHtml(result);
        return safeResult;
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsUnderlinePipe, deps: [{ token: i1.DomSanitizer }], target: i0.ɵɵFactoryTarget.Pipe }); }
    static { this.ɵpipe = i0.ɵɵngDeclarePipe({ minVersion: "14.0.0", version: "17.3.1", ngImport: i0, type: BsUnderlinePipe, isStandalone: true, name: "bsUnderline" }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsUnderlinePipe, decorators: [{
            type: Pipe,
            args: [{
                    name: 'bsUnderline',
                    pure: true,
                    standalone: true
                }]
        }], ctorParameters: () => [{ type: i1.DomSanitizer }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BsBoldPipe, BsItalicPipe, BsStrikethroughPipe, BsUnderlinePipe };
//# sourceMappingURL=mintplayer-ng-bootstrap-markdown.mjs.map
