import { AsyncPipe } from '@angular/common';
import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, HostListener } from '@angular/core';
import { takeUntilDestroyed } from '@angular/core/rxjs-interop';
import { BehaviorSubject, combineLatest, map } from 'rxjs';

class BsRatingComponent {
    constructor() {
        this.maximum$ = new BehaviorSubject(5);
        this.value$ = new BehaviorSubject(3);
        this.previewValue$ = new BehaviorSubject(null);
        //#endregion
        //#region Value
        this.valueChange = new EventEmitter();
        this.starsChange = new EventEmitter();
        this.stars$ = combineLatest([this.maximum$, this.previewValue$, this.value$])
            .pipe(map(([maximum, previewValue, value]) => {
            const v = previewValue ?? value;
            return [
                ...[...Array(v).keys()].map(i => true),
                ...[...Array(maximum - v).keys()].map(i => false)
            ];
        }));
        combineLatest([this.previewValue$, this.value$])
            .pipe(takeUntilDestroyed())
            .subscribe(([previewValue, value]) => {
            const v = previewValue ?? value;
            this.starsChange.emit(v);
        });
    }
    //#region Maximum
    set maximum(value) {
        this.maximum$.next(value);
    }
    get value() {
        return this.value$.value;
    }
    set value(value) {
        this.value$.next(value);
        this.valueChange.emit(value);
    }
    //#endregion
    hoverValue(index) {
        this.previewValue$.next(index + 1);
    }
    selectValue(index) {
        this.value = index + 1;
    }
    onMouseLeave() {
        this.previewValue$.next(null);
    }
    static { this.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsRatingComponent, deps: [], target: i0.ɵɵFactoryTarget.Component }); }
    static { this.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "17.0.0", version: "17.3.1", type: BsRatingComponent, isStandalone: true, selector: "bs-rating", inputs: { maximum: "maximum", value: "value" }, outputs: { valueChange: "valueChange", starsChange: "starsChange" }, host: { listeners: { "mouseleave": "onMouseLeave()" } }, ngImport: i0, template: "@for (star of (stars$ | async); let i = $index; track i) {\n    <span class=\"cursor-pointer\" (mouseenter)=\"hoverValue(i)\" (click)=\"selectValue(i)\">\n        {{ star ? '&#9733;' : '&#9734;' }}\n    </span>\n}", styles: [""], dependencies: [{ kind: "pipe", type: AsyncPipe, name: "async" }] }); }
}
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "17.3.1", ngImport: i0, type: BsRatingComponent, decorators: [{
            type: Component,
            args: [{ selector: 'bs-rating', standalone: true, imports: [AsyncPipe], template: "@for (star of (stars$ | async); let i = $index; track i) {\n    <span class=\"cursor-pointer\" (mouseenter)=\"hoverValue(i)\" (click)=\"selectValue(i)\">\n        {{ star ? '&#9733;' : '&#9734;' }}\n    </span>\n}" }]
        }], ctorParameters: () => [], propDecorators: { maximum: [{
                type: Input
            }], valueChange: [{
                type: Output
            }], starsChange: [{
                type: Output
            }], value: [{
                type: Input
            }], onMouseLeave: [{
                type: HostListener,
                args: ['mouseleave']
            }] } });

/**
 * Generated bundle index. Do not edit.
 */

export { BsRatingComponent };
//# sourceMappingURL=mintplayer-ng-bootstrap-rating.mjs.map
